==> nextcloud-app-contacts-2.1.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/es_SV.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactos",
    "Download" : "Descargar",
    "Copy link" : "Copiar liga",
    "Click to copy the link to your clipboard" : "Haz click para copiar la liga a tu porta papeles",
    "Toggle sharing" : "Alternar comparitr",
    "Delete" : "Borrar",
    "Rename" : "Renombrar",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "can edit" : "puede editar",
    "Close" : "Cerrar",
    "Enabled" : "Habilitado",
    "Disabled" : "Deshabilitado",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
    "Address book name" : "Nombre de la libreta de direcciones",
    "Only these special characters are allowed: -_.!?#|()" : "Sólo se permiten estos caracteres especiales: -_.!?#|()",
    "Address book could not be created." : "No fue posible crear la libreta de direcciones. ",
    "Upload new image" : "Cargar imagen nueva",
    "The selected image is too big (max 1MB)" : "La imagen seleccionada es demasiado grande (1MB máximo)",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Esta tarjeta estaba corrupta y ha sido arreglada. Por favor verifica los datos y has un guardado para hacer los cambios permanentes.",
    "No contacts in here" : "No hay contactos aquí",
    "Name" : "Nombre",
    "Organization" : "Organización",
    "Title" : "Título",
    "Add field …" : "Agregar campo ...",
    "Save changes" : "Guardar cambios",
    "Address book" : "Libreta de direcciones",
    "Loading contacts …" : "Cargando contactos ...",
    "Import into" : "Importar a",
    "Importing..." : "Importando...",
    "Select your addressbook" : "Selecciona tu libreta de contactos",
    "Import is disabled because no writable address book had been found." : "El importar está deshabilitado porque no se ha encontrado una libreta de direcciones a la que se pueda escribir.",
    "No search result for {query}" : "No se encontraron resultados para la búsqueda {query}",
    "All contacts" : "Todos los contactos",
    "Post office box" : "Apartado postal",
    "Postal code" : "Código postal",
    "City" : "Ciudad",
    "State or province" : "Estado o provincia",
    "Country" : "País",
    "Address" : "Dirección",
    "(new group)" : "(grupo nuevo)",
    "Last name" : "Apellido",
    "First name" : "Nombre",
    "Additional names" : "Nombres adicionales",
    "Prefix" : "Prefijo",
    "Suffix" : "Sufijo",
    "Importing into" : "Importando a",
    "New contact" : "Nuevo contacto",
    "Not grouped" : "No agrupado",
    "Sort by" : "Ordenar por",
    "There is no address book available to create a contact." : "No existe una libreta de direcciones disponible para crear el contacto.",
    "{addressbook} shared by {owner}" : "{addressbook} compartido por {owner}",
    "Contact not found." : "No se encontró el contacto.",
    "You don't have permission to write to this addressbook." : "No tienes los permisos para escribir en esta libreta de direcciones",
    "Contact could not be created." : "No fue posible crear el contacto.",
    "No contacts in file. Only vCard files are allowed." : "No se encontró ningún archivo de contactos. Solo se permiten archivos vCard.",
    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Sólo están soportadas las versiones 4.0 (RFC6350) o 3.0 (RFC2426) de los archivos vCard.",
    "Contact could not be moved." : "No se pudo mover el contacto.",
    "Contact could not be saved." : "No se pudo guardar el contacto.",
    "Waiting for the server to be ready…" : "Esperando a que el servidor esté listo...",
    "Importing…" : "Importando...",
    "Display name" : "Nombre a desplegar",
    "Nickname" : "Apodo",
    "Detailed name" : "Nombre detallado",
    "Notes" : "Notas",
    "Website" : "Sitio web",
    "Federated Cloud ID" : "Id de nube federada",
    "Home" : "Particular",
    "Work" : "Trabajo",
    "Other" : "Otro",
    "Groups" : "Grupos",
    "Birthday" : "Fecha de nacimiento",
    "Anniversary" : "Aniversario",
    "Date of death" : "Fecha de defunción",
    "Email" : "Correo electrónico",
    "Instant messaging" : "Mensajería instantánea",
    "Phone" : "Teléfono fijo",
    "Mobile" : "Teléfono móvil",
    "Work mobile" : "Número celular de trabajo",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax de trabajo",
    "Pager" : "Localizador",
    "Voice" : "Voz",
    "Car" : "Auto",
    "Work pager" : "Localizador de trabajo",
    "Social network" : "Red social",
    "Relationship" : "Relación",
    "Specify a relationship between you and the entity represented by this vCard." : "Especifica la relación entre tú y la entidad representada por esta vCard.",
    "Spouse" : "Cónyuge",
    "Child" : "Hijo",
    "Mother" : "Madre",
    "Father" : "Padre",
    "Parent" : "Padre",
    "Brother" : "Hermano",
    "Sister" : "Hermana",
    "Relative" : "Familiar",
    "Friend" : "Amigo",
    "Colleague" : "Colega",
    "Manager" : "Gerente",
    "Assistant" : "Asistente",
    "Related" : "Relacionado",
    "Specify a relationship between another entity and the entity represented by this vCard." : "Especifica la relación entre alguna otra entidad y la entidad representada por esta vCard.",
    "Contact" : "Contacto",
    "Agent" : "Agente",
    "Emergency" : "Emergencia",
    "Co-worker" : "Compañero de trabajo",
    "Gender" : "Género",
    "Female" : "Femenino",
    "Male" : "Masculino",
    "Details" : "Detalles",
    "Settings" : "Configuraciones "
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-contacts-3.1.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/es_SV.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactos",
    "All contacts" : "Todos los contactos",
    "Details" : "Detalles",
    "Loading" : "Cargando",
    "Name" : "Nombre",
    "Title" : "Título",
    "Download" : "Descargar",
    "Delete" : "Borrar",
    "Groups" : "Grupos",
    "New contact" : "Nuevo contacto",
    "No results" : "No hay resultados",
    "Last modified" : "Última modificación",
    "Rename" : "Renombrar",
    "Enabled" : "Habilitado",
    "Disabled" : "Deshabilitado",
    "Copy link" : "Copiar liga",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "can edit" : "puede editar",
    "Importing into" : "Importando a",
    "Import into" : "Importar a",
    "Address book name" : "Nombre de la libreta de direcciones",
    "First name" : "Nombre",
    "Last name" : "Apellido",
    "Display name" : "Nombre a desplegar",
    "Not grouped" : "No agrupado",
    "Nickname" : "Apodo",
    "Detailed name" : "Nombre detallado",
    "Additional names" : "Nombres adicionales",
    "Prefix" : "Prefijo",
    "Suffix" : "Sufijo",
    "Notes" : "Notas",
    "Website" : "Sitio web",
    "Location" : "Ubicación",
    "Federated Cloud ID" : "Id de nube federada",
    "Home" : "Particular",
    "Work" : "Trabajo",
    "Other" : "Otro",
    "Address" : "Dirección",
    "Post office box" : "Apartado postal",
    "City" : "Ciudad",
    "State or province" : "Estado o provincia",
    "Postal code" : "Código postal",
    "Country" : "País",
    "Birthday" : "Fecha de nacimiento",
    "Anniversary" : "Aniversario",
    "Date of death" : "Fecha de defunción",
    "Email" : "Correo electrónico",
    "Instant messaging" : "Mensajería instantánea",
    "Phone" : "Teléfono fijo",
    "Mobile" : "Teléfono móvil",
    "Work mobile" : "Número celular de trabajo",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax de trabajo",
    "Pager" : "Localizador",
    "Voice" : "Voz",
    "Car" : "Auto",
    "Work pager" : "Localizador de trabajo",
    "Social network" : "Red social",
    "Relationship" : "Relación",
    "Specify a relationship between you and the entity represented by this vCard." : "Especifica la relación entre tú y la entidad representada por esta vCard.",
    "Spouse" : "Cónyuge",
    "Child" : "Hijo",
    "Mother" : "Madre",
    "Father" : "Padre",
    "Parent" : "Padre",
    "Brother" : "Hermano",
    "Sister" : "Hermana",
    "Relative" : "Familiar",
    "Friend" : "Amigo",
    "Colleague" : "Colega",
    "Manager" : "Gerente",
    "Assistant" : "Asistente",
    "Related" : "Relacionado",
    "Specify a relationship between another entity and the entity represented by this vCard." : "Especifica la relación entre alguna otra entidad y la entidad representada por esta vCard.",
    "Contact" : "Contacto",
    "Agent" : "Agente",
    "Emergency" : "Emergencia",
    "Co-worker" : "Compañero de trabajo",
    "Gender" : "Género",
    "Female" : "Femenino",
    "Male" : "Masculino",
    "None" : "Ninguno",
    "Unknown" : "Desconocido",
    "Timezone" : "Zona horaria"
},
"nplurals=2; plural=(n != 1);");
